@@ -13,6 +13,19 @@ if sys.platform.find('free') > -1:
             if os.path.exists(name):
                 return name
         return find_library_orig(name)
+
+find_library_orig = find_library
+def find_library(name):
+    if sys.platform == "darwin":
+        libPath = os.environ.get('DYLD_LIBRARY_PATH', '')
+    else:
+        libPath = os.environ.get('LD_LIBRARY_PATH', '')
+    libPathList = libPath.split(':')
+    for path in libPathList:
+        pathName = path+'/lib%s.so' % name
+        if os.path.exists(pathName):
+            return pathName
+    return find_library_orig(name)
     
 import logging
 log = logging.getLogger('netsnmp')
@@ -120,6 +133,7 @@ netsnmp_session._fields_ = [
         ]
 
 
+
 dataFreeHook = CFUNCTYPE(c_void_p)
 
 class counter64(Structure):
@@ -293,7 +307,7 @@ decoder = {
     chr(ASN_BIT_STR): decodeString,
     chr(ASN_IPADDRESS): decodeIp,
     chr(ASN_COUNTER): lambda pdu: pdu.val.uinteger.contents.value,
-    chr(ASN_GAUGE): lambda pdu: pdu.val.integer.contents.value,
+    chr(ASN_GAUGE): lambda pdu: pdu.val.uinteger.contents.value,
     chr(ASN_TIMETICKS): lambda pdu: pdu.val.uinteger.contents.value,
     chr(ASN_COUNTER64): decodeBigInt,
     chr(ASN_APP_FLOAT): lambda pdu: pdu.val.float.contents.value,
@@ -496,7 +510,7 @@ class Session(object):
     
 
 MAXFD = 1024
-fdset = c_long * (MAXFD/32)
+fdset = c_int32 * (MAXFD/32)
 
 class timeval(Structure):
     _fields_ = [
